==> haskell-ghc-check-0.5.0.8-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-check.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-check
version:              0.5.0.8
visibility:           public
id:                   ghc-check-0.5.0.8-EzNHlgXuASgEHZvj4joUVb
key:                  ghc-check-0.5.0.8-EzNHlgXuASgEHZvj4joUVb
license:              BSD-3-Clause
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:
    detect mismatches between compile-time and run-time versions of the ghc api

description:
    detect mismatches between compile-time and run-time versions of the ghc api

category:             Development
abi:                  6ec9153ae4a782ad97e72237feaed49f
exposed:              True
exposed-modules:      GHC.Check GHC.Check.Executable GHC.Check.PackageDb
hidden-modules:       GHC.Check.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghc-check-0.5.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghc-check-0.5.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghc-check-0.5.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-check
hs-libraries:         HSghc-check-0.5.0.8-EzNHlgXuASgEHZvj4joUVb
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    ghc-9.4.8 ghc-boot-9.4.8 ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    process-1.6.18.0 safe-exceptions-0.1.7.4-9D2uepB9WTsDTqb2PanewV
    template-haskell-2.19.0.0 th-compat-0.1.6-DtdgScmMCcYJ5sASiujuK0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-ghc-check/html/ghc-check.haddock
haddock-html:         /usr/share/doc/haskell-ghc-check/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-check-0.5.0.8-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-check.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-check
version:              0.5.0.8
visibility:           public
id:                   ghc-check-0.5.0.8-4bwM7mIU9R2Fj1swiSXIpv
key:                  ghc-check-0.5.0.8-4bwM7mIU9R2Fj1swiSXIpv
license:              BSD-3-Clause
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:
    detect mismatches between compile-time and run-time versions of the ghc api

description:
    detect mismatches between compile-time and run-time versions of the ghc api

category:             Development
abi:                  955f2d9ed20c2ee5d15bc1433a3a1d03
exposed:              True
exposed-modules:      GHC.Check GHC.Check.Executable GHC.Check.PackageDb
hidden-modules:       GHC.Check.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghc-check-0.5.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghc-check-0.5.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghc-check-0.5.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-check
hs-libraries:         HSghc-check-0.5.0.8-4bwM7mIU9R2Fj1swiSXIpv
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    ghc-9.4.8 ghc-boot-9.4.8 ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    process-1.6.18.0 safe-exceptions-0.1.7.4-EQt22r9MxO6GW2uweSuhE1
    template-haskell-2.19.0.0 th-compat-0.1.6-JwbsifSaPB6JIE5pDP4B9w
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-ghc-check/html/ghc-check.haddock
haddock-html:         /usr/share/doc/haskell-ghc-check/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
